pub struct EmbeddedResources {
pub stdlib_path: PathBuf,
pub runtime_path: PathBuf,
/* private fields */
}Available on crate feature
embedded only.Expand description
Paths to extracted embedded resources.
Fields
stdlib_path: PathBufPath to the extracted Python standard library directory.
runtime_path: PathBufPath to the pre-compiled runtime file (for mmap loading).
Implementations
Sourceimpl EmbeddedResources
impl EmbeddedResources
Sourcepub fn get() -> Result<&'static Self, Error>
pub fn get() -> Result<&'static Self, Error>
Get the embedded resources, extracting them on first call.
Resources are extracted to a persistent temp directory that survives for the lifetime of the process. Subsequent calls return the same paths.
Errors
Returns an error if resource extraction fails.