ExecutionOutput

Struct ExecutionOutput 

#[non_exhaustive]
pub struct ExecutionOutput { pub stdout: String, pub stderr: String, pub peak_memory_bytes: u64, pub duration: Duration, pub callback_invocations: u32, pub fuel_consumed: Option<u64>, }
Output from executing Python code in the WASM sandbox.

This struct is #[non_exhaustive] to allow adding new fields in the future without breaking semver compatibility.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
stdout: String

Captured stdout from the Python execution.

stderr: String

Captured stderr from the Python execution.

peak_memory_bytes: u64

Peak memory usage in bytes during execution.

duration: Duration

Execution duration.

callback_invocations: u32

Number of callback invocations during execution.

fuel_consumed: Option<u64>

Fuel consumed during execution (if fuel tracking is enabled).

This measures the number of WASM instructions executed. Always present when the engine has fuel consumption enabled.

Implementations

Source

impl ExecutionOutput

pub fn new( stdout: String, stderr: String, peak_memory_bytes: u64, duration: Duration, callback_invocations: u32, fuel_consumed: Option<u64>, ) -> Self

Create a new execution output.