Available on crate feature
embedded-stdlib only.Expand description
Embedded Python standard library for use with custom runtimes.
This module provides extraction and caching of the embedded Python stdlib without requiring the full embedded runtime (~30MB+ savings).
Features
This module is available when the embedded-stdlib feature is enabled.
The full embedded feature implies embedded-stdlib.
Example
ⓘ
use eryx::embedded_stdlib::EmbeddedStdlib;
// Get path to embedded stdlib (extracts on first call)
let stdlib = EmbeddedStdlib::get()?;
let sandbox = unsafe {
Sandbox::builder()
.with_precompiled_file("/path/to/custom-runtime.cwasm")
.with_python_stdlib(stdlib.path())
.build()?
};Structs
- Embedded
Stdlib - Paths to the extracted embedded stdlib.